@@ -18,6 +18,8 @@ ANSI_CODES: dict[str, str] = {
     "{M": "\x1b[1;35m",
     "{C": "\x1b[1;36m",
     "{W": "\x1b[1;37m",
+    "{h": "\x1b[36m",
+    "{H": "\x1b[1;36m",
 }
 
 
